/**
 * Liste zu einem Zirkel verknpft
 * 
 * @author Hennchen
 * @version 2007-06-05
 */

public class Circle {

    /*
     * Innere Klasse, die eine Person im Kreis beschreibt.
     */
    private class Person {

        //Nummer der Person
        int number;

        //Verweis auf nchste Person
        Person next;

     /**
     * Erzeugt ein neues Element. Erwartet 2 Parameter
     * 
     * @param nr Die Nummer
     * @param ct Die nachfolgende Person
     * */
        Person (int nr, Person next) {
            this.number = nr;
            this.next = next;
        }
    }


    //Person bei der immer gestartet wird.
    Person start = null;

    /**
     * Liefert true zurck,
     * wenn keine start-Person vorhanden ist. Das heit
     * der Kreis ist dann leer.
     */
    public boolean isEmpty() {
        return start == null;
    }

	/**
	 * Gibt eine textuelle Reprsentation der Elemente
	 * der zirkulren Liste zurck.
	 */
    public String toString() {

		//Falls leere Liste, wird ein leerer String zurckgegeben.
		if (isEmpty()) return "";

		// StringBuffer zum zusammenfgen der Listenelemente
		StringBuffer returnString = new StringBuffer();

		//aktuelle Person ist start Person.
		Person actualPerson = start;
		do {
			//fge Nummer der Person an
			returnString.append(actualPerson.number);
			returnString.append(" ");

			//gehe zur nchsten Person
			actualPerson = actualPerson.next;

			//mache das solange, bis wir wieder
			//bei der ersteb sind.
		} while (actualPerson != start);

		return returnString.toString();
	}


    /**
     * Erzeugt neue Person mit angegebener Nummer und
     * fgt sie in die Liste ein. (vor dem Startelement)
     * 
     * @param value Der Wert der im neuen Objekt gespeichert wird
     */
    public void insert (int value) {
        if (isEmpty()) {
			//Falls leere Liste erzeuge Person,
			//die auf sich selbst zeigt.
            start = new Person(value, null);
            start.next = start;
        } else {

			Person actualPerson = start;
			do {
				actualPerson = actualPerson.next;
			} while (actualPerson.next != start);

			//Fge neue Person zwischen letzter und erster Person ein.
            actualPerson.next = new Person(value, start);
        }
    }


	/**
	 * Entfernt Person an angegebener Position und setzt start
	 * auf die stelle nach der entfernten Person.
	 * 
     * @param pos Die Position des zu entfernenden Objektes
	 */
    public int remove (int pos) {

        int removedValue = 0;
        Person actualPerson = start;

        if (!isEmpty()) {
			for (int i = 1; i < pos - 1; i++) {
				actualPerson = actualPerson.next;
			}
			//gehe zum Personenobjekt vor dem gesuchten Objekt.
			removedValue = actualPerson.next.number;

			if(actualPerson != actualPerson.next) {
				//Falls Person nicht auf sich selbst zeigt
				//Zeige auf die bernchste
				actualPerson.next = actualPerson.next.next;

				//Und setze Start auf die nun nchste
				start = actualPerson.next;
			} else {
				start = null;
			}
		}

        return removedValue;
    }



}

